==> agrosyst-cli-1.4.9-sources.jar: fr/inra/agrosyst/services/pz0import/effective/effectiveCropCycleSpecies/EffectiveCropCycleSpeciesImportModel.java <==
package fr.inra.agrosyst.services.pz0import.effective.effectiveCropCycleSpecies;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: EffectiveCropCycleSpeciesImportModel.java 4923 2015-05-05 15:53:56Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.4.9/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/effective/effectiveCropCycleSpecies/EffectiveCropCycleSpeciesImportModel.java $
 * %%
 * Copyright (C) 2013 - 2015 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.services.pz0import.AbstractAgrosystModelExtended;

/**
 * Created by davidcosse on 01/04/15.
 */
public class EffectiveCropCycleSpeciesImportModel extends AbstractAgrosystModelExtended<EffectiveCropCycleSpeciesImportDto> {

    protected EffectiveCropCycleSpeciesImportModel() {
        super(';');
        newMandatoryColumn("topiaid", "id");
        newIgnoredColumn("topiaversion");
        newIgnoredColumn("topiacreatedate");
        newMandatoryColumn("plantscertified", "plantsCertified", T_F_PARSER);
        newMandatoryColumn("overgraftdate", "overGraftDate");
        newMandatoryColumn("graftclone", "graftCloneId");// RefClonePlanGrape
        newMandatoryColumn("graftsupport", "graftSupportId");// RefVariete
        newMandatoryColumn("croppingplanspecies", "croppingPlanSpeciesId");
        newMandatoryColumn("effectiveperennialcropcycle", "effectivePerennialCropCycleId");
    }

    @Override
    public EffectiveCropCycleSpeciesImportDto newEmptyInstance() {
        return new EffectiveCropCycleSpeciesImportDto();
    }
}

==> agrosyst-cli-1.5.1-sources.jar: fr/inra/agrosyst/services/pz0import/effective/effectiveCropCycleSpecies/EffectiveCropCycleSpeciesImportModel.java <==
package fr.inra.agrosyst.services.pz0import.effective.effectiveCropCycleSpecies;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: EffectiveCropCycleSpeciesImportModel.java 5028 2015-07-10 06:33:13Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.5.1/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/effective/effectiveCropCycleSpecies/EffectiveCropCycleSpeciesImportModel.java $
 * %%
 * Copyright (C) 2013 - 2015 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.services.pz0import.AbstractAgrosystModelExtended;

/**
 * Created by davidcosse on 01/04/15.
 */
class EffectiveCropCycleSpeciesImportModel extends AbstractAgrosystModelExtended<EffectiveCropCycleSpeciesImportDto> {

    EffectiveCropCycleSpeciesImportModel() {
        super();
        newMandatoryColumn("topiaid", "id");
        newIgnoredColumn("topiaversion");
        newIgnoredColumn("topiacreatedate");
        newMandatoryColumn("plantscertified", "plantsCertified", T_F_PARSER);
        newMandatoryColumn("overgraftdate", "overGraftDate");
        newMandatoryColumn("graftclone", "graftCloneId");// RefClonePlanGrape
        newMandatoryColumn("graftsupport", "graftSupportId");// RefVariete
        newMandatoryColumn("croppingplanspecies", "croppingPlanSpeciesId");
        newMandatoryColumn("effectiveperennialcropcycle", "effectivePerennialCropCycleId");
    }

    @Override
    public EffectiveCropCycleSpeciesImportDto newEmptyInstance() {
        return new EffectiveCropCycleSpeciesImportDto();
    }
}
